obs_object_impl

Attribute Macro obs_object_impl 

#[obs_object_impl]
Implements the builder and updater logic for an OBS object.

This macro generates the implementation blocks for the builder and updater structs created by obs_object_builder and obs_object_updater. It should be applied to the implementation block of the main object struct.

Example

#[obs_object_impl]
impl MySource {
    // Custom methods...
}